@@ -25,6 +25,7 @@ from marionette import Marionette
 from marionette.by import By
 from marionette.errors import MarionetteException
 from marionette.gestures import smooth_scroll
+import mozdevice
 import mozlog
 import numpy
 
@@ -86,6 +87,8 @@ class DatazillaPerfPoster(object):
         self.submit_report = True
         self.ancillary_data = {}
         self.device = gaiatest.GaiaDevice(self.marionette)
+        dm = mozdevice.DeviceManagerADB()
+        self.device.add_device_manager(dm)
 
         if self.device.is_android_build:
             self.logger.debug('Getting gaia, gecko and build revisions')
@@ -208,7 +211,6 @@ class B2GPerfRunner(DatazillaPerfPoster):
         self.ancillary_data['settle_time'] = self.settle_time
 
     def measure_app_perf(self, app_names):
-        b2gpopulate = B2GPopulate(self.marionette)
         caught_exception = False
         self.marionette.set_script_timeout(60000)
         self.marionette.set_search_timeout(60000)
@@ -249,8 +251,7 @@ class B2GPerfRunner(DatazillaPerfPoster):
 
             test = test_class(self.marionette, app_name, self.logger,
                               self.iterations, self.delay, self.device,
-                              self.restart, self.settle_time, self.testvars,
-                              b2gpopulate)
+                              self.restart, self.settle_time, self.testvars)
             try:
                 test.run()
 
@@ -277,7 +278,7 @@ class B2GPerfRunner(DatazillaPerfPoster):
 class B2GPerfTest(object):
 
     def __init__(self, marionette, app_name, logger, iterations, delay,
-                 device, restart, settle_time, testvars, b2gpopulate):
+                 device, restart, settle_time, testvars):
         self.marionette = marionette
         self.app_name = app_name
         self.logger = logger
@@ -288,7 +289,7 @@ class B2GPerfTest(object):
         self.settle_time = settle_time
         self.testvars = testvars
         self.requires_connection = False
-        self.b2gpopulate = b2gpopulate
+        self.b2gpopulate = B2GPopulate(self.marionette)
 
     def connect_to_network(self):
         while not self.device.is_online:
@@ -652,8 +653,7 @@ class B2GPerfScrollHomescreenTest(B2GPerfScrollTest):
         pass
 
     def before_scroll(self):
-        self.app = gaiatest.GaiaApp(frame=self.marionette.find_element(
-            *self.homescreen._homescreen_iframe_locator))
+        self.app = gaiatest.GaiaApp(frame=self.apps.displayed_app.frame)
         self.marionette.switch_to_frame(self.app.frame)
 
     def scroll(self):
